package App::scan_prereqs_cpanfile;
use strict;
use warnings;
use 5.008005;
our $VERSION = "1.03";



1;
__END__

=head1 NAME

App::scan_prereqs_cpanfile - Scan prerequisite modules and generate CPANfile

=head1 DESCRIPTION

Please look L<scan-prereqs-cpanfile>.

=head1 LICENSE

Copyright (C) tokuhirom

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

tokuhirom E<lt>tokuhirom@gmail.comE<gt>

